@@ -25,9 +25,11 @@ def get_prepared_request(data):
     prepared.url = data["uri"]
     prepared._cookies = RequestsCookieJar()
     prepared.body = data["body"]
-    prepared.headers = [{'Content-Length': ['20']}]
+    prepared.headers = CaseInsensitiveDict([('Accept', '*/*')])
     if data.get('headers'):
         prepared.headers = CaseInsensitiveDict([(key, value[0]) for key, value in data["headers"].items()])
+    #if data.get('headers'):
+    #    prepared.headers = CaseInsensitiveDict(data["headers"])
     return prepared
 
 
@@ -43,11 +45,17 @@ def store_responses(replayed):
 
 
 def replay(cassette, cassette_path, status=None, uri=None, diff=None):
-    session = requests.Session()
+    #session = requests.Session()
     for interaction in filter_cassette(cassette["interactions"], status, uri):
-        request = get_prepared_request(interaction["request"])
+        request = interaction["request"]
+        if not request.get('headers'):
+           request['headers'] = {}
+        else:
+            request['headers'] = CaseInsensitiveDict([(key, value[0]) for key, value in request["headers"].items()])
+        #request = get_prepared_request(interaction["request"])
         with d_vcr.use_cassette(f'new_{cassette_path}'):
-            response = session.send(request)
+            response = requests.post(request['uri'], headers=request['headers'], data=request['body'])
+            #response = session.send(request)
             replayed = Replayed(interaction, response)
             yield replayed
             cheks.check_status_code(replayed)
