@@ -1,3 +1,5 @@
+import json
+
 import click
 import yaml
 
@@ -16,7 +18,7 @@ def differ():
     """Command line tool for testing your web application"""
 
 
-@differ.command()
+#@differ.command()
 @click.argument("cassette_path", type=click.Path(exists=True))
 @click.option("--uri", help="A regexp that filters interactions by their request URI.", required=False, type=str)
 @click.option("--diff", '-d',  help="Comparing new response with the old", required=False, type=bool)
